@@ -8,20 +8,10 @@ skip_conditionally()
 
 test_that("Setup with seed works (use 2 for testing)", {
   options("jlmerclusterperm.nthreads" = 2)
-  expect_true(jlmerclusterperm_setup(restart = TRUE))
+  expect_true(jlmerclusterperm_setup(cache_dir = tempdir(), restart = TRUE))
+  expect_true(file.exists(file.path(tempdir(), "julia", "Manifest.toml")))
   expect_equal(JuliaConnectoR::juliaEval("Threads.nthreads()"), 2)
 })
-#
-# test_that("Restart as default", {
-#   expect_true(jlmerclusterperm_setup(verbose = FALSE))
-# })
-#
-# test_that("Don't restart if FALSE", {
-#   setup_is_ok <- julia_setup_ok()
-#   if (setup_is_ok) {
-#     expect_message(jlmerclusterperm_setup(restart = FALSE), "already running")
-#   }
-# })
 
 test_that("RNG initializes to seed=1 counter=0", {
   expect_equal(get_rng_seed(), 1)
